Crate mux_media

Crate mux_media 

Re-exports

pub use config::Config;
pub use config::ConfigTarget;
pub use media_info::MediaInfo;

Modules

config
media_info

Macros

dashed
Returns a CliArg string with leading dashes (e.g. "--input").
immut
Initializes a MediaInfo value if need and immutably borrows it.
lang
Returns a Lang::Code.
undashed
Returns a CliArg string without leading dashes (e.g. "input").

Structs

ArcPathBuf
A wrapper around Arc<PathBuf>.
CodecId
A wrapper around ffmpeg::codec::id::Id.
Duration
A wrapper around std::time::Duration.
GlobSetPattern
A wrapper around GlobSet with its raw pattern string.
MediaNumber
Stores a numbers extracted from OsStr.
MuxLogger
A logger imlementing the log logger.
RangeUsize
A wrapper around Range<usize>.
Stream
A stream info.
StreamsOrder
A sorted order of streams.
StreamsOrderItem
A StreamsOrder item.

Enums

CharEncoding
A charaster encoding of file.
CliArg
A CLI argument.
DispositionType
A type of disposition.
Extension
A supported file extension.
Lang
A language, either LangCode or any string.
LangCode
A language code of ISO 639-1 in ISO 639-3 representation or undeterminated code (Und).
Msg
A message with localized methods.
MuxError
StreamType
A type of stream.
Target
A target of ConfigTarget.
Value
A value, either auto or user-defined.

Traits

Field
Associates a field with the marker type F.
LazyField
Associates a lazily initialized field with the marker type F.
LazyPathField
Associates a lazily initialized field with the marker type F and Path.
ToTxtConfig
Converts a value to txt config arguments.
TryFinalizeInit
Provides a delayed initialization for expensive operations.

Functions

ensure_long_path_prefix
Returns a path unchanged (Unix).
mux
Tries run muxing, returning a count of successfully muxed media files.
run
Tries run muxing, taking settings from the arguments that this program was started with (normally passed via the command line).

Type Aliases

Error
Result