LangCode

Enum LangCode 

#[non_exhaustive]
pub enum LangCode {
Show 185 variants Und, Aar, Abk, Afr, Aka, Alb, Amh, Ara, Arg, Arm, Asm, Ava, Ave, Aym, Aze, Bak, Bam, Baq, Bel, Ben, Bis, Bos, Bre, Bul, Bur, Cat, Cha, Che, Chi, Chu, Chv, Cor, Cos, Cre, Cze, Dan, Div, Dut, Dzo, Eng, Epo, Est, Ewe, Fao, Fij, Fin, Fre, Fry, Ful, Geo, Ger, Gla, Gle, Glg, Glv, Gre, Grn, Guj, Hat, Hau, Hbs, Heb, Her, Hin, Hmo, Hrv, Hun, Ibo, Ice, Ido, Iii, Iku, Ile, Ina, Ind, Ipk, Ita, Jav, Jpn, Kal, Kan, Kas, Kau, Kaz, Khm, Kik, Kin, Kir, Kom, Kon, Kor, Kua, Kur, Lao, Lat, Lav, Lim, Lin, Lit, Ltz, Lub, Lug, Mac, Mah, Mal, Mao, Mar, May, Mlg, Mlt, Mon, Nau, Nav, Nbl, Nde, Ndo, Nep, Nno, Nob, Nor, Nya, Oci, Oji, Ori, Orm, Oss, Pan, Per, Pli, Pol, Por, Pus, Que, Roh, Rum, Run, Rus, Sag, San, Sin, Slo, Slv, Sme, Smo, Sna, Snd, Som, Sot, Spa, Srd, Srp, Ssw, Sun, Swa, Swe, Tah, Tam, Tat, Tel, Tgk, Tgl, Tha, Tib, Tir, Ton, Tsn, Tso, Tuk, Tur, Twi, Uig, Ukr, Urd, Uzb, Ven, Vie, Vol, Wel, Wln, Wol, Xho, Yid, Yor, Zha, Zul,
}
A language code of ISO 639-1 in ISO 639-3 representation or undeterminated code (Und).

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Und



Aar



Abk



Afr



Aka



Alb



Amh



Ara



Arg



Arm



Asm



Ava



Ave



Aym



Aze



Bak



Bam



Baq



Bel



Ben



Bis



Bos



Bre



Bul



Bur



Cat



Cha



Che



Chi



Chu



Chv



Cor



Cos



Cre



Cze



Dan



Div



Dut



Dzo



Eng



Epo



Est



Ewe



Fao



Fij



Fin



Fre



Fry



Ful



Geo



Ger



Gla



Gle



Glg



Glv



Gre



Grn



Guj



Hat



Hau



Hbs



Heb



Her



Hin



Hmo



Hrv



Hun



Ibo



Ice



Ido



Iii



Iku



Ile



Ina



Ind



Ipk



Ita



Jav



Jpn



Kal



Kan



Kas



Kau



Kaz



Khm



Kik



Kin



Kir



Kom



Kon



Kor



Kua



Kur



Lao



Lat



Lav



Lim



Lin



Lit



Ltz



Lub



Lug



Mac



Mah



Mal



Mao



Mar



May



Mlg



Mlt



Mon



Nau



Nav



Nbl



Nde



Ndo



Nep



Nno



Nob



Nor



Nya



Oci



Oji



Ori



Orm



Oss



Pan



Per



Pli



Pol



Por



Pus



Que



Roh



Rum



Run



Rus



Sag



San



Sin



Slo



Slv



Sme



Smo



Sna



Snd



Som



Sot



Spa



Srd



Srp



Ssw



Sun



Swa



Swe



Tah



Tam



Tat



Tel



Tgk



Tgl



Tha



Tib



Tir



Ton



Tsn



Tso



Tuk



Tur



Twi



Uig



Ukr



Urd



Uzb



Ven



Vie



Vol



Wel



Wln



Wol



Xho



Yid



Yor



Zha



Zul