Re-exports
pub use config::Config;pub use config::ConfigTarget;pub use media_info::MediaInfo;
Modules
Macros
- dashed
- Returns a
CliArgstring with leading dashes (e.g."--input"). - immut
- Initializes a
MediaInfovalue if need and immutably borrows it. - lang
- Returns a
Lang::Code. - undashed
- Returns a
CliArgstring without leading dashes (e.g."input").
Structs
- ArcPath
Buf - A wrapper around
Arc<PathBuf>. - CodecId
- A wrapper around
ffmpeg::codec::id::Id. - Duration
- A wrapper around
std::time::Duration. - Glob
SetPattern - A wrapper around
GlobSetwith its raw pattern string. - Media
Number - Stores a numbers extracted from
OsStr. - MuxLogger
- A logger imlementing the
loglogger. - Range
Usize - A wrapper around
Range<usize>. - Stream
- A stream info.
- Streams
Order - A sorted order of streams.
- Streams
Order Item - A
StreamsOrderitem.
Enums
- Char
Encoding - A charaster encoding of file.
- CliArg
- A CLI argument.
- Disposition
Type - A type of disposition.
- Extension
- A supported file extension.
- Lang
- A language, either
LangCodeor any string. - Lang
Code - A language code of ISO 639-1 in ISO 639-3 representation or undeterminated code (
Und). - Msg
- A message with localized methods.
- MuxError
- Stream
Type - A type of stream.
- Target
- A target of
ConfigTarget. - Value
- A value, either auto or user-defined.
Traits
- Field
- Associates a field with the marker type
F. - Lazy
Field - Associates a lazily initialized field with the marker type
F. - Lazy
Path Field - Associates a lazily initialized field with the marker type
FandPath. - ToTxt
Config - Converts a value to txt config arguments.
- TryFinalize
Init - Provides a delayed initialization for expensive operations.
Functions
- ensure_
long_ path_ prefix - Returns a path unchanged (Unix).
- mux
- Tries run muxing, returning a count of successfully muxed media files.
- run
- Tries run muxing, taking settings from the arguments that this program was started with (normally passed via the command line).